use std::path::PathBuf;

use structopt::StructOpt;

#[derive(StructOpt, Debug)]
#[structopt(name = "mkroot")]
pub struct Config {
	/// OS name (for /etc/os-release)
	#[structopt(long, name = "OSNAME", default_value = "mkroot")]
	pub osname: String,

	/// OS version (for /etc/os-release)
	#[structopt(long, name = "OSVERSION", default_value = "1.0")]
	pub osversion: String,

	/// Verbose
	#[structopt(short, long)]
	pub verbose: bool,

	/// Path to LDD
	#[structopt(long, name = "LDD", default_value = "/usr/bin/ldd", parse(from_os_str))]
	pub ldd: PathBuf,

	/// Directory for root filesystem
	#[structopt(required = true, name = "DIR", parse(from_os_str))]
	pub root_dir: PathBuf,

	/// Files to parse
	#[structopt(required = true, name = "FILES", parse(from_os_str))]
	pub files: Vec<PathBuf>,
}
