use std::fs::{metadata, set_permissions, File};
use std::io::{BufWriter, Write};
use std::os::unix::fs::PermissionsExt;
use std::path::PathBuf;

use crate::config::Config;
use crate::error::MkrootResult;

pub fn os_release(config: &Config) -> MkrootResult<()> {
	if config.verbose {
		println!("Creating file etc/os-release");
	}

	let mut path = PathBuf::from(&config.root_dir);
	path.push("etc/os-release");

	{
		let f = File::create(&path)?;
		let mut writer = BufWriter::new(f);
		writer.write_fmt(format_args!(
			"NAME=\"{}\"\nVERSION=\"{}\"\n",
			&config.osname, &config.osversion
		))?;
	}

	let mut perms = metadata(&path)?.permissions();
	perms.set_mode(0o644);
	set_permissions(&path, perms)?;

	Ok(())
}
